import React, { useState } from "react";
import { useDispatch, useSelector } from "react-redux";
import { useNavigate } from "react-router-dom";

import { loading, selectIsLoading } from "@redux/loaderSlice";
import { auth, setUserInfo } from "@redux/outstaffingSlice";
import { setRole } from "@redux/roleSlice";

import { apiRequest } from "@api/request";

// import { useNotification } from "@hooks/useNotification";
import BaseButton from "@components/Common/BaseButton/BaseButton";
import { Loader } from "@components/Common/Loader/Loader";
import ModalLayout from "@components/Common/ModalLayout/ModalLayout";

import "./modalAuth.scss";

export const ModalAuth = ({ active, setActive }) => {
  const navigate = useNavigate();
  const dispatch = useDispatch();
  const isLoading = useSelector(selectIsLoading);
  const [error, setError] = useState(null);
  const [modalError, setModalError] = useState(false);
  const [formData, setFormData] = useState({
    email: "",
    password: ""
  });

  const closeModal = () => {
    setActive(false);
  };

  const handleChange = (e) => {
    const { name, value } = e.target;
    setFormData({
      ...formData,
      [name]: value
    });
  };

  const submitHandler = () => {
    if (!isLoading) {
      dispatch(loading(true));
      apiRequest("/user/login", {
        method: "POST",
        data: formData
      }).then((res) => {
        if (!res.access_token) {
          setError("Введены некорректные данные для входа");
          setModalError(true);
          dispatch(loading(false));
        } else {
          localStorage.setItem("auth_token", res.access_token);
          localStorage.setItem("id", res.id);
          localStorage.setItem("cardId", res.card_id);
          localStorage.setItem("role_status", res.status);
          localStorage.setItem(
            "access_token_expired_at",
            res.access_token_expired_at
          );
          dispatch(auth(true));
          dispatch(setUserInfo(res));
          dispatch(loading(false));
          dispatch(setRole("ROLE_PARTNER"));
          navigate("/profile");
        }
      });
    }
  };

  return (
    <ModalLayout active={active} setActive={closeModal} styles={"auth"}>
      <div className="auth-body__main">
        <h2 className="auth-body__main-title">
          Войти к <span>ITguild</span>
        </h2>
        <div className="input-body">
          <div className="input-body__box">
            <div className="input-container">
              <h5>E-mail</h5>
              <input
                type="email"
                name="email"
                onChange={handleChange}
                value={formData.email}
                placeholder="Почта"
                id="authEmail"
              />
            </div>
          </div>

          <div className="input-body__box">
            <div className="input-container">
              <h5>Пароль</h5>
              <input
                type="password"
                name="password"
                onChange={handleChange}
                value={formData.password}
                placeholder="Пароль"
                id="authPassword"
              />
            </div>
          </div>
        </div>
        <span className="error">{modalError ? error : ""}</span>
        <div className="button-box">
          <BaseButton
            onClick={async (e) => {
              e.preventDefault();
              submitHandler(e);
            }}
            styles="button-box__submit"
          >
            {isLoading ? <Loader /> : "Войти"}
          </BaseButton>
        </div>
      </div>
      <span onClick={() => closeModal()} className="exit"></span>
    </ModalLayout>
  );
};

export default ModalAuth;
