import React from "react";
import { Navigate, Route, Routes } from "react-router-dom";

import { Auth } from "@pages/Auth/Auth";
import { CompanyInfo } from "@pages/CompanyInfo/CompanyInfo";
import { Forms } from "@pages/Forms/Forms";
import { Landing } from "@pages/Landing/Landing";
import { LandingTracker } from "@pages/LandingTracker/LandingTracker";
import { OpenRequest } from "@pages/OpenRequests/OpenRequest";
import { PartnerSettings } from "@pages/PartnerSettings/PartnerSettings";
import { PartnerTreaties } from "@pages/PartnerTreaties/PartnerTreaties";
import { Payouts } from "@pages/Payouts/Payouts";
import { Profile } from "@pages/Profile/Profile";
import { ProjectTracker } from "@pages/ProjectTracker/ProjectTracker";
import { PassingTests } from "@pages/Quiz/PassingTests";
import { QuizPage } from "@pages/Quiz/QuizPage";
import { QuizReportPage } from "@pages/Quiz/QuizReportPage";
import { Stack } from "@pages/Stack/Stack";
import Statistics from "@pages/Statistics/Statistics";
import { Summary } from "@pages/Summary/Summary";
import { Tracker } from "@pages/Tracker/Tracker";
import { TrackerIntro } from "@pages/TrackerIntro/TrackerIntro";
import { Vacancy } from "@pages/Vacancy/Vacancy";
import { ViewReport } from "@pages/ViewReport/ViewReport";
import { WelcomePage } from "@pages/WelcomePage/WelcomePage";

import TicketFullScreen from "@components/Modal/Tracker/TicketFullScreen/TicketFullScreen";
import { ProfileCalendar } from "@components/ProfileCalendar/ProfileCalendar";
import { ReportForm } from "@components/ReportForm/ReportForm";

export const DeveloperPage = () => {
  return (
    <Routes>
      <Route exact path="/auth" element={<Auth />} />
      <Route exact path="/welcome-page" element={<WelcomePage />} />
      <Route exact path="/stack" element={<Stack />} />
      <Route exact path="/landing-tracker" element={<LandingTracker />} />
      <Route exact path="/" element={<Landing />} />
      <Route path="*" element={<Navigate to="/auth" replace />} />
      <Route exact path="/tracker-intro" element={<TrackerIntro />} />
      <Route exact path="/forms" element={<Forms />} />
      <Route exact path="/company" element={<CompanyInfo />} />

      <Route exact path="/tracker/task/:id" element={<TicketFullScreen />} />
      <Route
        exact
        path="/tracker/project/:id/task/:taskId"
        element={<ProjectTracker />}
      />
      <Route exact path="/tracker/project/:id" element={<ProjectTracker />} />

      <Route exact path="profile">
        <Route index element={<Profile />} />
        <Route exact path="calendar" element={<ProfileCalendar />} />
        <Route exact path="calendar/report" element={<ReportForm />} />
        <Route exact path="calendar/view/:date/:id" element={<ViewReport />} />
        <Route exact path="open-requests" element={<OpenRequest />} />
        <Route exact path="open-requests/:id" element={<Vacancy />} />
        <Route exact path="summary" element={<Summary />} />
        <Route exact path="tracker" element={<Tracker />} />
        <Route exact path="statistics/:id" element={<Statistics />} />
        <Route exact path="payouts" element={<Payouts />} />
        <Route exact path="settings" element={<PartnerSettings />} />
        <Route exact path="treaties" element={<PartnerTreaties />} />
        <Route exact path="quiz">
          <Route index element={<QuizPage />} />
          <Route exact path="test/:uuid" element={<PassingTests />} />
          <Route exact path="report/:uuid" element={<QuizReportPage />} />
        </Route>
      </Route>
      {/* <Route path="*" element={<Navigate to="/profile" replace />} /> */}
    </Routes>
  );
};
